from setuptools import setup
from setuptools import find_packages
 

setup(
name='arbaz',
version='1.1.1',
description='Analysis between Sales vs Time by accessing google sheet from google drive',
long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),  
author='Arbaz Khan',
url='https://github.com/ArbazKhan7/Greendeck-Task2',
author_email='arbazkhanak7777@gmail.com',
license='MIT', 
classifiers = [
'Development Status :: 5 - Production/Stable',
'Intended Audience :: Education',
'Operating System :: Microsoft :: Windows :: Windows 10',
'License :: OSI Approved :: MIT License',
'Programming Language :: Python :: 3.8'
],
keywords='', 
packages=find_packages(),
install_requires=[''] ,
include_package_data=True,

)



    ###############                     MAIN CODE              ###################

import  gspread

import matplotlib.pyplot as plt

from oauth2client.service_account import ServiceAccountCredentials

scope = ["https://www.googleapis.com/auth/spreadsheets","https://www.googleapis.com/auth/drive.file","https://www.googleapis.com/auth/drive"]

creds = ServiceAccountCredentials.from_json_keyfile_name('credentials.json',scope)

client = gspread.authorize(creds)

sheet= client.open_by_key('1SrZfvr2ee54r7HR1jGtAE9zHIj_Y-UzK9ok8bdwkpqc').sheet1

#print(sheet.get_all_records())




x1= sheet.col_values(1)    #time_stamp
x2 = sheet.col_values(2)   #average_sales
 

plt.bar(x1, x2,color='g')
plt.ylabel('Sales')
plt.xlabel('Time_Stamp')
plt.title('Greendeck')
plt.show()






